# `vbjax`

`vbjax` is a Jax-based package for working with virtual brain style models.

## Usage

Installs with `pip install vbjax`, or manually install dependencies with
`pip install numpy scipy jax jaxlib` or `conda install -y numpy scipy jax`.

Please see various notebooks and unit tests for usage.

## Development

```
git clone https://github.com/ins-amu/vbjax
cd vbjax
pip install '.[test]'
pytest
```
